@@ -5,17 +5,15 @@
 
 =head1 NAME
 
-Set::Infinite::Date - 'date' scalar - Deprecated - use Date::Set instead
+Set::Infinite::Date - a 'date' scalar
 
 =head1 SYNOPSIS
 
-This module is obsolete - use Date::Set instead
-
 	use Set::Infinite::Date;
 
 	$a = Set::Infinite::Date->new("10:00");
 
-	This module requires Time::Local
+	This module requires HTTP:Date and Time::Local
 
 =head1 USAGE
 
@@ -46,7 +44,7 @@ Date input format:
 
 String conversion functions:
 
-	0 + $s	returns the Date as a time-number (epoch).
+	0 + $s	returns the Date as a time-number. 
 			This is faster than	date2time or hour2time.
 
 	time2date 
@@ -66,9 +64,8 @@ String conversion functions:
 Internal functions:
 	$a->mode($b);
 		mode can be 
-		0 - epoch
-		1 - beginning in 00:00:00 
-		2 - absolute dates like 2001-01-01 00:00:00
+		1 (beginning in 00:00:00) or 
+		2 (absolute dates like 2001-01-01 00:00:00)
 
 =head1 TODO
 
@@ -83,96 +80,73 @@ Internal functions:
 
 require Exporter;
 package Set::Infinite::Date;
+$VERSION = "0.17";
 
 my $DEBUG = 1;
+my $package = 'Set::Infinite::Date';
+# @ISA = qw(Set::Infinite::Simple); # DON'T !
 @EXPORT = qw();
 @EXPORT_OK = qw(
-	time2date date2time time2hour hour2time 
+	time2date date2time time2hour hour2time quantizer day_size
 );
 
 use strict;
-use warnings;
-use Carp;
+use HTTP::Date qw(str2time);
 use Time::Local;
-use Set::Infinite::Element_Inf;
-
-#--- THIS FUNCTION IS (HEAVILY) MODIFIED FROM HTTP::Date -- Copyright 1995-1999, Gisle Aas
-
-sub str2time {
-    my $str = shift;    # '1996-02-29 12:00:00' 
-    my @d = $str =~ 
-	/(\d{4})-(\d\d?)-(\d\d?)
-     (?:
-	       (?:\s+)  # separator before clock
-	    (\d\d?):?(\d\d)    # hour:min
-	    (?::?(\d\d(?:\.\d*)?))?  # optional seconds (and fractional)
-	 )?                    # optional clock
-	/x; 
-    $d[0] -= 1900;  # year
-    $d[1]--;        # month
-    $d[3] = 0 unless $d[3];
-    $d[4] = 0 unless $d[4];
-    $d[5] = 0 unless $d[5];
-	# print " # $str == ", join(";",@d), " \n";
-    return timegm(reverse @d);
-}
-
-#--- END CODE DERIVED FROM HTTP::Date
 
 use overload
-	'0+' => sub { return $_[0]->{a} },
 	'<=>' => \&spaceship,
+	'cmp' => \&cmp,
 	'-' => \&sub,
 	'+' => \&add,
 	'/' => \&div,
 	qw("" as_string);
 
+our $quantizer = 'Set::Infinite::Quantize_Date';
+our $selector  = 'Set::Infinite::Select';
+our $offsetter = 'Set::Infinite::Offset';
 
-our $day_size = timegm(0,0,0,2,3,2001) - timegm(0,0,0,1,3,2001);
+our $day_size = timelocal(0,0,0,2,3,2001) - timelocal(0,0,0,1,3,2001);
 our $hour_size = $day_size / 24;
 our $minute_size = $hour_size / 60;
 our $second_size = $minute_size / 60;
 
 our $date_format = "year-month-day hour:min:sec";
 
-our %date_cache = ();
-our %time2date_cache = ();
+sub day_size { $day_size }
+
+sub quantizer {
+	# if (@_) {
+	#	$quantizer = pop;
+	# }
+	return $quantizer;
+}
 
 sub date_format {
 	$date_format = pop if @_;
-	# %date_cache = ();
-	%time2date_cache = ();
 	return $date_format;
 }
 
 # export time2date and date2time
-
 sub time2date (;$)  { 
-	my $a = shift;
-	if (exists $time2date_cache{$a}) { 
-		# print "*"; 
-		return $time2date_cache{$a} 
-	};
-	# print " [ttd:$a] ";
-
-	my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime($a);
+	my $tmp = shift;
+	my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime($tmp);
 	$year += 1900;
 	$mon++;
 	foreach ($sec,$min,$hour,$mday,$mon,$year) {
 		$_ = '0' . $_ if $_ < 10;
 	}
-	my $tmp = $date_format;
+	$tmp = $date_format;
 	$tmp =~ s/year/$year/;
 	$tmp =~ s/month/$mon/;
 	$tmp =~ s/day/$mday/;
 	$tmp =~ s/sec/$sec/;
 	$tmp =~ s/min/$min/;
 	$tmp =~ s/hour/$hour/;
-	$time2date_cache{$a} = $tmp;
 	return $tmp;
 }
 
-sub date2time ($;$) { return str2time (shift) }
+sub date2time ($;$) { return HTTP::Date::str2time (shift) }
 
 sub time2hour {
 	my $a = shift;
@@ -202,24 +176,20 @@ sub div {
 sub sub {
 	# TODO: (since 0.21) keep format ("mode") in result (see: "Date::add")
 	my ($tmp1, $tmp2, $inverted) = @_;
-	my $result;
-	$tmp2 = Set::Infinite::Date->new($tmp2) unless ref($tmp2) and (ref($tmp2) eq __PACKAGE__);
+	$tmp2 = Set::Infinite::Date->new($tmp2) unless ref($tmp2) and $tmp2->isa(__PACKAGE__);
 	if ($inverted) {
 		return - $tmp1 if $tmp2->is_null;
-		$result = Set::Infinite::Date->new( $tmp2->{a} - $tmp1->{a} );
-		$result->{mode} = $tmp2->{mode};
+		return Set::Infinite::Date->new( $tmp2->{a} - $tmp1->{a} );
 	}
 	return $tmp1 unless defined($tmp2);
-	$result = Set::Infinite::Date->new( $tmp1->{a} - $tmp2->{a} );
-	$result->{mode} = $tmp1->{mode};
-	return $result;
+	return Set::Infinite::Date->new( $tmp1->{a} - $tmp2->{a} );
 }
 
 sub add {
 	my ($tmp1, $tmp2, $inverted) = @_;
 	return $tmp1 unless defined($tmp2);
 	# print " [DATE::ADD $tmp1 $tmp2] ";
-	$tmp2 = Set::Infinite::Date->new($tmp2) unless ref($tmp2) eq __PACKAGE__;
+	$tmp2 = Set::Infinite::Date->new($tmp2) unless ref($tmp2) and $tmp2->isa(__PACKAGE__);
 	my $result = Set::Infinite::Date->new( $tmp1->{a} + $tmp2->{a} );
 	if ($inverted) {
 		$result->{mode} = $tmp2->{mode};
@@ -232,57 +202,56 @@ sub add {
 
 sub spaceship {
 	my ($tmp1, $tmp2, $inverted) = @_;
+	# print " [DATE:CMP:",caller(1),"]\n";
+	# print " $tmp1 ";
+
+	return 1 unless defined($tmp2);
+
+	# if ($DEBUG) {
+		# if ($tmp2->isa(__PACKAGE__)) {
+		#	print " [DATE:CMP:$inverted:",$tmp1->{a};
+		#	print " [ ",$tmp2,": ", ref($tmp2), ": ", ref(\$tmp2), "]\n";
+		#	print "    <=>",$tmp2->{a},"]\n";
+		#}
+		# { else {
+		#	print " [DATE:CMP:$inverted:",$tmp1;
+		#	print " [ ",$tmp2,": ", ref($tmp2), ": ", ref(\$tmp2), "]\n";
+		#	print "    <=>",$tmp2,"]\n";
+		# }
+	# }
+
+	$tmp2 = Set::Infinite::Date->new($tmp2) unless ref($tmp2) and $tmp2->isa(__PACKAGE__);
+
 	if ($inverted) {
-		return ( $tmp2 <=> $tmp1->{a} );
+		return ( $tmp2->{a} <=> $tmp1->{a} );
 	}
+	return ( $tmp1->{a} <=> $tmp2->{a} );
+}
 
-        # my @caller = caller(1);
-        # print " [",$caller[1],":",$caller[2]," <=> $tmp1 $tmp2 ]\n" ;
-
-	return ( $tmp1->{a} <=> $tmp2 );
+sub cmp {
+	return spaceship @_;
 }
 
 sub new {
-	my $class = shift;
-	my $self;
-	if (ref($class)) {
-		$self = bless { mode => $class->{mode} }, ref($class);
-	}
-	else {
-		$self = bless {}, $class;
-	}
+	my ($self) = bless {}, shift;
 	my $tmp = shift;
-
-	if ((not defined $tmp) or ($tmp eq '')) {
-		# print " [date:new:null] ";
-		return Set::Infinite::Element_Inf->null ;
-	}
-
-	if (exists $date_cache{$tmp}) {
-		# print "*";
-        ### TODO: this breaks t/date_select_offset.t test #12
-        ###    because it is mixing modes 0 and 2
-		### return $date_cache{$tmp};
-	}
-	# print "N";
 	$tmp = '' unless defined $tmp;
 	$self->{string} = '';
 	if ($tmp =~ /\d[\/\.\-]\d/) {
 		# $self->{string} = $tmp;
 		$self->{a} = date2time($tmp);
-		$self->{mode} = 2 unless $self->{mode};
+		$self->{mode} = 2;
 	}
 	elsif ($tmp =~ /\d\:\d/) {
 		# $self->{string} = $tmp;
 		$self->{a} = hour2time($tmp);
-		$self->{mode} = 1 unless $self->{mode};
+		$self->{mode} = 1;
 	}
 	else {
 		# $self->{string} = $tmp;
 		$self->{a} = $tmp;
-		$self->{mode} = 0 unless $self->{mode};
+		$self->{mode} = 0;
 	}
-	$date_cache{$tmp} = $self;
 	return $self;
 }
 
@@ -298,7 +267,6 @@ sub as_string {
 
 	#return '' unless defined($self);
 	#print " [ $self->{string} ] " ;
-	# $self->{string} = '';
 
 	if ($self->{string} ne '') {
 		# done
@@ -321,4 +289,26 @@ sub as_string {
 	return $self->{string};
 }
 
-1;
+# TIE
+
+sub TIESCALAR {
+	my $class = shift;
+	my $self = $class->new(@_);
+	return $self;
+}
+
+sub FETCH {
+	my ($self) = shift;
+	return $self->as_string;
+}
+
+sub STORE {
+	my ($self) = shift;
+	$self = new(@_);
+	return @_;
+}
+
+sub DESTROY {
+}
+
+1;
\ No newline at end of file
